WlanAssociationConfig

Struct WlanAssociationConfig 

pub struct WlanAssociationConfig {
Show 14 fields pub bssid: Option<[u8; 6]>, pub aid: Option<u16>, pub listen_interval: Option<u16>, pub primary: Option<ChannelNumber>, pub qos: Option<bool>, pub wmm_params: Option<WlanWmmParameters>, pub rates: Option<Vec<u8>>, pub capability_info: Option<u16>, pub ht_cap: Option<HtCapabilities>, pub ht_op: Option<HtOperation>, pub vht_cap: Option<VhtCapabilities>, pub vht_op: Option<VhtOperation>, pub bandwidth: Option<ChannelBandwidth>, pub vht_secondary_80_channel: Option<ChannelNumber>, /* private fields */
}
Argument table to be passed as the single argument to WlanSoftmac.NotifyAssociationComplete. All information here is relevant only in the context of the association with the given peer_addr. All fields in this table are required unless stated otherwise.

Fields

bssid: Option<[u8; 6]>

The MAC address of the peer with which we are now associated.

aid: Option<u16>

A unique identifier for this specific association. This is unique among active associations, not necessarily historical ones.

listen_interval: Option<u16>primary: Option<ChannelNumber>

The channel on which we have associated with this peer.

qos: Option<bool>

QoS capable and parameters

wmm_params: Option<WlanWmmParameters>

WFA WMM v1.2, 2.2.2

rates: Option<Vec<u8>>

Concatenation of SupportedRates and ExtendedSupportedRates IEEE Std 802.11-2016, 9.4.2.3 & 9.4.2.13

capability_info: Option<u16>

IEEE Std 802.11-2016, 9.4.1.4

ht_cap: Option<HtCapabilities>

IEEE Std 802.11-2016, 9.4.2.56, 57 Rx MCS Bitmask in Supported MCS Set field represents the set of MCS the peer can receive at from this device, considering this device’s Tx capability.

ht_op: Option<HtOperation>vht_cap: Option<VhtCapabilities>

IEEE Std 802.11-2016, 9.4.2.158, 159

vht_op: Option<VhtOperation>bandwidth: Option<ChannelBandwidth>vht_secondary_80_channel: Option<ChannelNumber>