WlanSoftmacBaseEnableBeaconingRequest

Struct WlanSoftmacBaseEnableBeaconingRequest 

pub struct WlanSoftmacBaseEnableBeaconingRequest {
    pub packet_template: Option<WlanTxPacket>,
    pub tim_ele_offset: Option<u64>,
    pub beacon_interval: Option<u16>,
    /* private fields */
}

Fields

packet_template: Option<WlanTxPacket>

Beacon template. Since this is a template, some packet content can only contain minimal valid information, because the content is later modified by hardware, firmware, or software.

tim_ele_offset: Option<u64>

TIM offset to the start of the packet_template field in bytes. This must index the first byte of the TIM IE, which is the tag ID.

beacon_interval: Option<u16>

Beacon interval period in TU.